# DataCenter

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**create_by** | **str** |  | [optional] 
**lng_lat** | [**Point**](Point.md) |  | [optional] 
**one_frontend_id** | **str** |  | 
**region_id** | **str** |  | [optional] 
**renewable_energy** | **bool** |  | [optional] 
**supplier_name** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


